@@ -3,6 +3,7 @@
 #!/usr/bin/python3
 import argparse
 
+from .apps import apps_args_configuration
 from .auth import login_args_configuration
 from .deploy import deploy_args_configuration
 from .scaffold import scaffold_args_configuration
@@ -18,6 +19,7 @@ def init_argparse() -> argparse.ArgumentParser:
     login_args_configuration(sub_parser)
     scaffold_args_configuration(sub_parser)
     deploy_args_configuration(sub_parser)
+    apps_args_configuration(sub_parser)
 
     return main_parser
 
